@@ -6,9 +6,9 @@ MailDocument <-
              description = character(0), header = character(0), heading = character(0), id = character(0),
              origin = character(0), language = character(0), localmetadata = list())
 {
-    doc <- tm:::.TextDocument(as.character(x), author, datetimestamp, description, heading, id, origin, language, localmetadata)
+    doc <- tm::PlainTextDocument(x, author, datetimestamp, description, heading, id, origin, language, localmetadata)
     attr(doc, "Header") <- header
-    class(doc) <- c("MailDocument", "PlainTextDocument", "TextDocument", "character")
+    class(doc) <- unique(c("MailDocument", class(doc)))
     doc
 }
 
